File manager

Dependencies:   SDFileSystem

Dependents:   RwSDCard_Xml_GPS

Revision:
6:5bd75c0f607c
Parent:
5:7c513eee7b2b
Child:
7:ab015947e368
Child:
8:5af4e12c43b2
--- a/FileManager.cpp	Mon May 16 08:29:39 2016 +0000
+++ b/FileManager.cpp	Tue May 17 10:22:32 2016 +0000
@@ -404,10 +404,20 @@
                 /* Found variable  address TAG, populate it*/
                 FileManager_GetXmlText(buf , m_varList[index].varAddress);
             }
-            else if (strstr (buf,VAR_SIZE_TAG)) 
+            else if (strstr (buf,VAR_LSB1_TAG)) 
+            {
+                /* Found variable  LSB1 TAG, populate it*/
+                FileManager_GetXmlText(buf , m_varList[index].varLSB1);
+            }
+            else if (strstr (buf,VAR_LSB2_TAG)) 
             {
-                /* Found variable  size TAG, populate it*/
-                FileManager_GetXmlText(buf , m_varList[index].varSize);
+                /* Found variable  LSB2 TAG, populate it*/
+                FileManager_GetXmlText(buf , m_varList[index].varLSB2);
+            }
+            else if (strstr (buf,VAR_BITMASK_TAG)) 
+            {
+                /* Found variable  BitMask TAG, populate it*/
+                FileManager_GetXmlText(buf , m_varList[index].varBitMask);
             }
             else if (strstr (buf,VAR_UNIT_TAG)) 
             {